/*********************************************************
 *
 * MIDI_NumAssign.c
 *
 * Authors: Ben McQuiston
 *
 * C function to assign a MIDI number to a note, based on position
 *   on staff, number of sharps and flats, and treble or bass cleff
 * 
 * Last Revision: 
 *       - November 13, 2006
 *  
 *****************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define MID_E 64
#define LOW_E 43
#define UP 1
#define DOWN -1

int 
MIDI_SharpFlatAdjust(int keySig, int MIDInum);

/****************************************************************
 *
 * int MIDI_NumAssign(int position, int keySig, int cleff)
 *
 * Arguments: position on staff from bottom staff line
 *            key signature: 1-7 = sharps, 0 = no sharps or flats
 *               -1..-7 = flats
 *            cleff: 1 = treble, -1 = bass
 *
 * Return value: MIDI number for note passed
 *
 * This function will find the corresponding MIDI number for 
 *   for a note that is passed to it based on its cleff, key signature,
 *   and position on the staff.
 *
 *****************************************************************/

int 
MIDI_NumAssign(int position, int keySig, int cleff)
{
	int temp = 0;
	int dir = 0;
	int i = 0;
	int j = 0;
	int counter = 0;

	printf("Key Sig: %d\n",keySig);

	if (position >= 0){
		dir = UP;
	}
	else{
		dir = DOWN;
		position = position * -1;
    }

	if (cleff == 1){
		temp = MID_E;
	}
	else{
		temp = LOW_E;
	}

	printf("temp initial: %d\n",temp);

  for (j = (position / 7); j >= 0 ; j--){
		if (j == 0){
			counter = position % 7;
		}
		else{
			counter = 7;
		}
	if (dir == UP){

      for (i = 0; i < counter; i++){
	    if ((i == 0) || (i == 4)){
	      temp++;
		  /*printf("temp 1: %d\n",temp);*/
	    }
	    else{
		  temp++;
		  temp++;
		 /* printf("temp 2: %d\n",temp);*/
	    }
	  }
	}
	else if (dir == DOWN){
      for (i = 0; i < counter; i++){
	    if ((i == 2) || (i == 6)){
	      temp--;
	    }
	    else{
		  temp--;
		  temp--;
		}
	  }
	}
  }
  
  /*call sharps and flats adjust...*/
  temp = MIDI_SharpFlatAdjust(keySig,temp);
  printf("temp final: %d\n",temp);
  
  return temp;
}
